@@ -13,7 +13,7 @@ import os
 import subprocess
 import sys
 
-from .utils import make_sure_path_exists, unicode_open, work_in
+from .utils import make_sure_path_exists, work_in
 
 _HOOKS = [
     'pre_gen_project',
