@@ -13,22 +13,39 @@ import errno
 import logging
 import os
 import sys
+import stat
+import shutil
 import contextlib
 
 
-PY3 = sys.version > '3'
-if PY3:
-    pass
-else:
-    import codecs
+def force_delete(func, path, exc_info):
+    """
+    Error handler for `shutil.rmtree()` equivalent to `rm -rf`
+    Usage: `shutil.rmtree(path, onerror=force_delete)`
+    From stackoverflow.com/questions/1889597
+    """
+
+    os.chmod(path, stat.S_IWRITE)
+    func(path)
+
+
+def rmtree(path):
+    """
+    Removes a directory and all its contents. Like rm -rf on Unix.
+
+    :param path: A directory path.
+    """
+
+    shutil.rmtree(path, onerror=force_delete)
 
 
 def make_sure_path_exists(path):
     """
     Ensures that a directory exists.
+
     :param path: A directory path.
     """
-    
+
     logging.debug("Making sure path exists: {0}".format(path))
     try:
         os.makedirs(path)
@@ -38,17 +55,6 @@ def make_sure_path_exists(path):
     return True
 
 
-def unicode_open(filename, *args, **kwargs):
-    """
-    Opens a file as usual on Python 3, and with UTF-8 encoding on Python 2.
-    :param filename: Name of file to open.
-    """
-    kwargs['encoding'] = "utf-8"
-    if PY3:
-        return open(filename, *args, **kwargs)
-    return codecs.open(filename, *args, **kwargs)
-
-
 @contextlib.contextmanager
 def work_in(dirname=None):
     """
