@@ -37,22 +37,28 @@ try:
 except KeyError:
     travis = False
 
+try:
+    no_network = os.environ[u'DISABLE_NETWORK_TESTS']
+except KeyError:
+    no_network = False
+
 from cookiecutter import config, utils
-from tests import force_delete, CookiecutterCleanSystemTestCase
+from tests import CookiecutterCleanSystemTestCase
 
 
 logging.basicConfig(format='%(levelname)s: %(message)s', level=logging.DEBUG)
 
 
 @unittest.skipIf(condition=travis, reason='Works locally with tox but fails on Travis.')
+@unittest.skipIf(condition=no_network, reason='Needs a network connection to GitHub.')
 class TestPyPackage(CookiecutterCleanSystemTestCase):
 
 
     def tearDown(self):
         if os.path.isdir('cookiecutter-pypackage'):
-            shutil.rmtree('cookiecutter-pypackage', onerror=force_delete)
+            utils.rmtree('cookiecutter-pypackage')
         if os.path.isdir('boilerplate'):
-            shutil.rmtree('boilerplate', onerror=force_delete)
+            utils.rmtree('boilerplate')
         super(TestPyPackage, self).tearDown()
 
     def test_cookiecutter_pypackage(self):
@@ -79,14 +85,15 @@ class TestPyPackage(CookiecutterCleanSystemTestCase):
 
 
 @unittest.skipIf(condition=travis, reason='Works locally with tox but fails on Travis.')
+@unittest.skipIf(condition=no_network, reason='Needs a network connection to GitHub.')
 class TestJQuery(CookiecutterCleanSystemTestCase):
 
 
     def tearDown(self):
         if os.path.isdir('cookiecutter-jquery'):
-            shutil.rmtree('cookiecutter-jquery', onerror=force_delete)
+            utils.rmtree('cookiecutter-jquery')
         if os.path.isdir('boilerplate'):
-            shutil.rmtree('boilerplate', onerror=force_delete)
+            utils.rmtree('boilerplate')
         super(TestJQuery, self).tearDown()
 
     def test_cookiecutter_jquery(self):
@@ -113,14 +120,15 @@ class TestJQuery(CookiecutterCleanSystemTestCase):
 
 
 @unittest.skipIf(condition=travis, reason='Works locally with tox but fails on Travis.')
+@unittest.skipIf(condition=no_network, reason='Needs a network connection to GitHub.')
 class TestExamplesRepoArg(CookiecutterCleanSystemTestCase):
 
     def tearDown(self):
         with utils.work_in(config.DEFAULT_CONFIG['cookiecutters_dir']):
             if os.path.isdir('cookiecutter-pypackage'):
-                shutil.rmtree('cookiecutter-pypackage', onerror=force_delete)
+                utils.rmtree('cookiecutter-pypackage')
         if os.path.isdir('boilerplate'):
-            shutil.rmtree('boilerplate', onerror=force_delete)
+            utils.rmtree('boilerplate')
         super(TestExamplesRepoArg, self).tearDown()
 
     def test_cookiecutter_pypackage_git(self):
@@ -138,14 +146,15 @@ class TestExamplesRepoArg(CookiecutterCleanSystemTestCase):
 
 
 @unittest.skipIf(condition=travis, reason='Works locally with tox but fails on Travis.')
+@unittest.skipIf(condition=no_network, reason='Needs a network connection to GitHub.')
 class TestGitBranch(CookiecutterCleanSystemTestCase):
 
     def tearDown(self):
         with utils.work_in(config.DEFAULT_CONFIG['cookiecutters_dir']):
             if os.path.isdir('cookiecutter-pypackage'):
-                shutil.rmtree('cookiecutter-pypackage', onerror=force_delete)
+                utils.rmtree('cookiecutter-pypackage')
         if os.path.isdir('boilerplate'):
-            shutil.rmtree('boilerplate', onerror=force_delete)
+            utils.rmtree('boilerplate')
         super(TestGitBranch, self).tearDown()
 
     def test_branch(self):
